Cross-platform directory lookup for Clojure, ClojureScript on Node, and ClojureDart.
The public API returns strings or vectors of strings and never creates directories.
See config-home, data-home, state-home, and home-dir.
Cross-platform directory lookup for Clojure, ClojureScript on Node, and ClojureDart. The public API returns strings or vectors of strings and never creates directories. - arity 0 returns the base directory - arity 1 appends an application name - arity 2 appends qualifier, organization, and application using platform rules See [[config-home]], [[data-home]], [[state-home]], and [[home-dir]].
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |